@@ -1,5 +1,5 @@
 # Standard Library
-from typing import Any, Dict, Iterable, Optional, Union
+from typing import Any, Dict, Iterable, Mapping, Optional, Union
 
 # Django
 from django.http import HttpRequest, HttpResponse, StreamingHttpResponse
@@ -41,28 +41,6 @@ class TurboStreamStreamingResponse(TurboStreamResponseMixin, StreamingHttpRespon
     """
 
 
-class TurboStreamIterableResponse(TurboStreamResponseMixin, HttpResponse):
-    """Handles turbo-stream iterator responses. Each item should be wrapped in
-    turbo-stream tags.
-
-    For example:
-
-    .. code-block:: python
-
-        return TurboStreamIterableResponse(
-            [
-                render_turbo_stream(
-                    "OK",
-                    Action.REPLACE,
-                    target=f"item-{i}"
-                ) for i in range(3)
-            ]
-        )
-    .. deprecated :: 0.0.29
-        use TurboStreamResponse
-    """
-
-
 class TurboStreamResponse(TurboStreamResponseMixin, HttpResponse):
     """Basic turbo-stream response.
 
@@ -74,13 +52,13 @@ class TurboStreamResponse(TurboStreamResponseMixin, HttpResponse):
 
     def __init__(
         self,
-        content: Union[str, Iterable] = "",
+        content: Union[Iterable[str], str] = "",
         *,
         action: Optional[Action] = None,
         target: Optional[str] = None,
         **kwargs,
     ):
-        if action and target:
+        if action and target and isinstance(content, str):
             content = render_turbo_stream(action, target, content)
         super().__init__(content, **kwargs)
 
@@ -157,7 +135,7 @@ class TurboFrameTemplateResponse(TemplateResponse):
         self,
         request: HttpRequest,
         template: Union[str, Iterable[str]],
-        context: Optional[Dict[str, Any]] = None,
+        context: Optional[Mapping[str, Any]] = None,
         *,
         dom_id,
         **kwargs,
@@ -166,7 +144,7 @@ class TurboFrameTemplateResponse(TemplateResponse):
         super().__init__(
             request,
             template,
-            {**context, "turbo_frame_dom_id": dom_id, "is_turbo_frame": True},
+            {**(context or {}), "turbo_frame_dom_id": dom_id, "is_turbo_frame": True},
             **kwargs,
         )
 
