@@ -19,6 +19,8 @@ from .mixins import (
     TurboFormModelMixin,
     TurboFrameResponseMixin,
     TurboFrameTemplateResponseMixin,
+    TurboStreamFormMixin,
+    TurboStreamFormModelMixin,
     TurboStreamResponseMixin,
     TurboStreamTemplateResponseMixin,
 )
@@ -52,6 +54,18 @@ class TurboUpdateView(TurboFormModelMixin, UpdateView):
     ...
 
 
+class TurboStreamFormView(TurboStreamFormMixin, FormView):
+    ...
+
+
+class TurboStreamCreateView(TurboStreamFormModelMixin, CreateView):
+    ...
+
+
+class TurboStreamUpdateView(TurboStreamFormModelMixin, UpdateView):
+    ...
+
+
 class TurboStreamDeleteView(TurboStreamResponseMixin, DeleteView):
     """Handles a delete action, returning an empty turbo-stream "remove"
     response. The target will be automatically resolved as {model_name}-{PK}.
